@@ -1,4 +1,5 @@
-package UNIVERSAL;
+package UNIVERSAL::moniker;
+$UNIVERSAL::moniker::VERSION = '0.02';
 
 =head1 NAME
 
@@ -35,6 +36,7 @@ So, if $ob->isa("Cephalopod::Octopus"), C<plural_moniker> will return "octopuses
 
 =cut
 
+package UNIVERSAL;
 use strict;
 use warnings;
 use Lingua::EN::Inflect 'PL';
